CryptoError

Enum CryptoError 

#[non_exhaustive]
pub enum CryptoError { SignatureInvalid, SignatureMalformed(String), KeyParseFailed(String), AidNotEd25519(String), AlgMismatch(String), TypMismatch { expected: String, got: String, }, JwsMalformed(String), }
Errors returned by signing, verifying, and key parsing operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SignatureInvalid

Signature verification returned a cryptographic failure.



SignatureMalformed(String)

Signature string was not valid base64url or wrong length.



KeyParseFailed(String)

Public key bytes could not be parsed as an Ed25519 key.



AidNotEd25519(String)

AID identifier did not decode to a valid 32-byte Ed25519 key.



AlgMismatch(String)

Compact-JWS header alg is not the sole value derived from the signer’s AID (RFC-AITP-0001 5.4.5). Includes none in any capitalization and unknown algorithms. Wire code: TOKEN_ALG_MISMATCH.



TypMismatch

Compact-JWS header typ does not exactly match the value expected for the verification context (RFC-AITP-0001 5.4.5). Wire code: TOKEN_TYP_MISMATCH.

Fields

expected: String

The typ value required by the verification context.

got: String

The typ value found in the protected header.



JwsMalformed(String)

Compact JWS failed strict parsing (RFC-AITP-0001 5.4.5): wrong segment count, empty segment, non-base64url characters, padding, or a malformed protected header.