#[non_exhaustive]pub enum CryptoError {
SignatureInvalid,
SignatureMalformed(String),
KeyParseFailed(String),
AidNotEd25519(String),
}Expand description
Errors returned by signing, verifying, and key parsing operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SignatureInvalid
Signature verification returned a cryptographic failure.
SignatureMalformed(String)
Signature string was not valid base64url or wrong length.
KeyParseFailed(String)
Public key bytes could not be parsed as an Ed25519 key.
AidNotEd25519(String)
AID identifier did not decode to a valid 32-byte Ed25519 key.